@@ -1,23 +1,23 @@
 /***
  *** message printing tools
- *** Written by Koen Gadeyne (kmg@barco.be)
+ *** (c) 1995 Koen Gadeyne (kmg@barco.be)
  ***
- *** version : 0.2
  ***/
 
 #include <stdio.h>
 #include <stdarg.h>
 #include "messages.h"
+
+int msgtype;  
   
-
-char msgtype[20];
-
 void print_msg(char *format,...)
 {
+  char *typstr[4] = { "DEBUG: " , "" , "WARNING: " , "ERROR: " };
   va_list argptr;
+
+  if ((msgtype==MSGTYP_DBG) && (debug_messages==FALSE)) return;
   va_start(argptr,format);
-  fprintf(stderr,"%s: ", CommandName);
-  if (msgtype[0] != '\0') fprintf(stderr,"%s: ", msgtype);
+  fprintf(stderr,"%s: %s", CommandName, typstr[msgtype]);
   vfprintf(stderr,format,argptr);
   va_end(argptr);
   fputc('\n',stderr);
